/****************************************************************************
** Meta object code from reading C++ file 'videoqueue.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasmatube-26.04.1/src/controllers/videoqueue.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videoqueue.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10VideoQueueE_t {};
} // unnamed namespace

template <> constexpr inline auto VideoQueue::qt_create_metaobjectdata<qt_meta_tag_ZN10VideoQueueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VideoQueue",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Use PlasmaTube.videoController",
        "currentVideoChanged",
        "",
        "queueChanged",
        "refresh",
        "markAsWatched",
        "index",
        "markAsUnwatched",
        "removeFromPlaylist",
        "plid",
        "clear",
        "playInQueue",
        "loadPlaylist",
        "playlistId",
        "loadPlaylistAndPlay",
        "videoId",
        "shouldBeVisible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentVideoChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queueChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'markAsWatched'
        QtMocHelpers::SlotData<void(int)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'markAsUnwatched'
        QtMocHelpers::SlotData<void(int)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'removeFromPlaylist'
        QtMocHelpers::SlotData<void(const QString &, int)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 12 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'playInQueue'
        QtMocHelpers::MethodData<void(int)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'loadPlaylist'
        QtMocHelpers::MethodData<void(const QString &)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'loadPlaylistAndPlay'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shouldBeVisible'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<VideoQueue, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VideoQueue::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10VideoQueueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10VideoQueueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10VideoQueueE_t>.metaTypes,
    nullptr
} };

void VideoQueue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideoQueue *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentVideoChanged(); break;
        case 1: _t->queueChanged(); break;
        case 2: _t->refresh(); break;
        case 3: _t->markAsWatched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->markAsUnwatched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->removeFromPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->clear(); break;
        case 7: _t->playInQueue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->loadPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->loadPlaylistAndPlay((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VideoQueue::*)()>(_a, &VideoQueue::currentVideoChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoQueue::*)()>(_a, &VideoQueue::queueChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->shouldBeVisible(); break;
        default: break;
        }
    }
}

const QMetaObject *VideoQueue::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VideoQueue::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10VideoQueueE_t>.strings))
        return static_cast<void*>(this);
    return AbstractListModel::qt_metacast(_clname);
}

int VideoQueue::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void VideoQueue::currentVideoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void VideoQueue::queueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
